@@ -21,12 +21,13 @@ from mock import Mock
 
 from freezer_api.api.common import middleware
 
+
 class TestHealthApp(unittest.TestCase):
 
     def test_call_nested_app(self):
         mock_app = Mock()
         mock_app.return_value = ['app_body']
-        health_app = middleware.HealthApp(mock_app, 'test_path_78908')
+        health_app = middleware.HealthApp(mock_app)
         environ = {}
         start_response = Mock()
         result = health_app(environ, start_response)
@@ -35,8 +36,8 @@ class TestHealthApp(unittest.TestCase):
     def test_return_200_when_paths_match(self):
         mock_app = Mock()
         mock_app.return_value = ['app_body']
-        health_app = middleware.HealthApp(mock_app, 'test_path_6789')
-        environ = {'PATH_INFO': 'test_path_6789'}
+        health_app = middleware.HealthApp(mock_app)
+        environ = {'PATH_INFO': '/v1/health'}
         start_response = Mock()
         result = health_app(environ, start_response)
         start_response.assert_called_once_with('200 OK', [])
